@@ -1,5 +1,5 @@
 # Copyright: 2001-2005 The Perl Foundation.  All Rights Reserved.
-# $Id: optimize.pm 11662 2006-02-19 03:22:51Z jhoblitt $
+# $Id: optimize.pm 12004 2006-03-24 14:13:06Z leo $
 
 =head1 NAME
 
@@ -22,7 +22,7 @@ use base qw(Parrot::Configure::Step::Base);
 use Config;
 use Parrot::Configure::Step;
 
-$description = "Enabling optimization...";
+$description = 'Enabling optimization';
 
 @args = qw(verbose optimize);
 
@@ -40,9 +40,13 @@ sub runstep
         $conf->data->add(' ', ccflags => "-DDISABLE_GC_DEBUG=1 -DNDEBUG");
         if ($optimize eq "1") {
             # use perl5's value
-            $conf->data->add(' ', ccflags => $Config{optimize});
+	    # gcc 4.1 doesn't like -mcpu=xx, i.e. it's deprecated
+	    # XXX do we know compiler (version) already?
+	    my $opts = $Config{optimize};
+	    $opts =~ s/-mcpu=\S+//;
+            $conf->data->add(' ', ccflags => $opts);
             # record what optimization was enabled
-            $conf->data->set(optimize => $Config{optimize});
+            $conf->data->set(optimize => $opts);
         } else {
             # use what was passed to --optimize on the CLI
             $conf->data->add(' ', ccflags => $optimize);
