@@ -1,7 +1,7 @@
 /* sub.h
  *  Copyright: 2001-2003 The Perl Foundation.  All Rights Reserved.
- *  CVS Info
- *     $Id: sub.h 11235 2006-01-18 00:19:14Z leo $
+ *  SVN Info
+ *     $Id: sub.h 11903 2006-03-14 20:49:11Z bernhard $
  *  Overview:
  *  Data Structure and Algorithms:
  *     Subroutine, coroutine, closure and continuation structures
@@ -58,7 +58,11 @@ typedef struct Parrot_sub {
     size_t   end_offs;
 
     INTVAL   HLL_id;            /* see src/hll.c XXX or per segment? */
-    PMC      *namespace;       /* where this Sub is in */
+    PMC      *namespace;        /* where this Sub is in - this is either
+                                   a String or a [Key] and describes
+                                   the relative path in the NameSpace  
+                                */
+    PMC      *namespace_stash;  /* the actual hash, HLL::namespace */
     STRING   *name;             /* name of the sub */
     PMC      *multi_signature;  /* list of types for MMD */
     INTVAL   n_regs_used[4];	/* INSP in PBC */
@@ -83,7 +87,11 @@ typedef struct Parrot_coro {
     size_t   end_offs;
 
     INTVAL   HLL_id;            /* see src/hll.c XXX or per segment? */
-    PMC      *namespace;       /* where this Sub is in */
+    PMC      *namespace;        /* where this Sub is in - this is either
+                                   a String or a [Key] and describes
+                                   the relative path in the NameSpace  
+                                */
+    PMC      *namespace_stash;  /* the actual hash, HLL::namespace */
     STRING   *name;             /* name of the sub */
     PMC      *multi_signature;  /* list of types for MMD */
     INTVAL   n_regs_used[4];	/* INSP in PBC */
