@@ -1,5 +1,5 @@
-# Copyright: 2004 The Perl Foundation.  All Rights Reserved.
-# $Id: Path.pm 5757 2004-03-27 22:23:02Z mikescott $
+# Copyright: 2004-2006 The Perl Foundation.  All Rights Reserved.
+# $Id: Path.pm 11790 2006-03-04 20:17:22Z bernhard $
 
 =head1 NAME
 
@@ -23,6 +23,7 @@ package Parrot::IO::Path;
 
 use strict;
 use warnings;
+
 use File::Path;
 use File::Spec;
 # qw() to avoid the export because we have a stat() method.
@@ -39,46 +40,46 @@ created and cached. A relative path is made absolute.
 
 sub new
 {
-	my $self = ref $_[0] ? ref shift : shift;
-	my $path = shift;
-	
-	return undef unless defined $path;
-	
-	$path = File::Spec->rel2abs($path);
-	
-	# Clean up any /foo/../ stuff.
-	while ( $path =~ s|/[^/]+/\.\.|| ) {}
+    my $self = ref $_[0] ? ref shift : shift;
+    my $path = shift;
+    
+    return unless defined $path;
+    
+    $path = File::Spec->rel2abs($path);
+    
+    # Clean up any /foo/../ stuff.
+    while ( $path =~ s|/[^/]+/\.\.|| ) {}
 
-	if ( exists $instance_for_path{$path} )
-	{
-		if ( ref($instance_for_path{$path}) ne $self )
-		{
-			bless $instance_for_path{$path}, $self;
-		}
-		
-		return $instance_for_path{$path};
-	}
-	
-	my ($volume, $directories, $name) = File::Spec->splitpath($path);
-	
-	# Needs '' to avoid a warning.
-	my $parent_path = File::Spec->catpath($volume, $directories, '');
-	
-	# To remove the trailing slash.
-	$parent_path = File::Spec->canonpath($parent_path);
-	
-	# If we are root then the above will make parent the same as path.
-	undef $parent_path if $parent_path eq $path;
-	
-	$self = bless {
-		PATH => $path,
-		NAME => $name,
-		PARENT_PATH => $parent_path,
-	}, $self;
-	
-	return undef unless $self->create_path;
-	
-	return $instance_for_path{$path} = $self;
+    if ( exists $instance_for_path{$path} )
+    {
+        if ( ref($instance_for_path{$path}) ne $self )
+        {
+            bless $instance_for_path{$path}, $self;
+        }
+        
+        return $instance_for_path{$path};
+    }
+    
+    my ($volume, $directories, $name) = File::Spec->splitpath($path);
+    
+    # Needs '' to avoid a warning.
+    my $parent_path = File::Spec->catpath($volume, $directories, '');
+    
+    # To remove the trailing slash.
+    $parent_path = File::Spec->canonpath($parent_path);
+    
+    # If we are root then the above will make parent the same as path.
+    undef $parent_path if $parent_path eq $path;
+    
+    $self = bless {
+        PATH => $path,
+        NAME => $name,
+        PARENT_PATH => $parent_path,
+    }, $self;
+    
+    return unless $self->create_path;
+    
+    return $instance_for_path{$path} = $self;
 }
 
 =back
@@ -96,17 +97,17 @@ Subclasses should reimplement this method to complete the task.
 
 sub create_path
 {
-	my $self = shift;
-	
-	return 1 unless $self->parent_path;
-	
-	unless ( -e $self->parent_path )
-	{
-		# This dies if it fails.
-		mkpath($self->parent_path);
-	}
-	
-	return -e $self->parent_path;
+    my $self = shift;
+    
+    return 1 unless $self->parent_path;
+    
+    unless ( -e $self->parent_path )
+    {
+        # This dies if it fails.
+        mkpath($self->parent_path);
+    }
+    
+    return -e $self->parent_path;
 }
 
 =item C<path()>
@@ -117,9 +118,9 @@ Returns the actual path.
 
 sub path
 {
-	my $self = shift;
-	
-	return $self->{PATH};
+    my $self = shift;
+    
+    return $self->{PATH};
 }
 
 =item C<name()>
@@ -130,9 +131,9 @@ Returns the name part of the path.
 
 sub name
 {
-	my $self = shift;
-	
-	return $self->{NAME};
+    my $self = shift;
+    
+    return $self->{NAME};
 }
 
 =item C<name_without_suffix()>
@@ -143,12 +144,12 @@ This will give you the name minus any .xyz suffix.
 
 sub name_without_suffix
 {
-	my $self = shift;
-	my $name = $self->name;
-	
+    my $self = shift;
+    my $name = $self->name;
+    
     $name =~ s/\.[^\.]*$//o;
     
-    return $name;	
+    return $name;    
 }
 
 =item C<suffix()>
@@ -160,15 +161,15 @@ suffix then the empty string is returned.
 
 sub suffix
 {
-	my $self = shift;
-	
-	return $self->{SUFFIX} if exists $self->{SUFFIX};
-	
-	my ($suffix) = $self->name =~ /\.([^.]+)$/;
-	
-	$self->{SUFFIX} = defined $suffix ? $suffix : '';
-	
-	return $self->{SUFFIX};
+    my $self = shift;
+    
+    return $self->{SUFFIX} if exists $self->{SUFFIX};
+    
+    my ($suffix) = $self->name =~ /\.([^.]+)$/;
+    
+    $self->{SUFFIX} = defined $suffix ? $suffix : '';
+    
+    return $self->{SUFFIX};
 }
 
 =item C<has_suffix()>
@@ -186,16 +187,16 @@ then this method will return true.
 
 sub has_suffix
 {
-	my $self = shift;
-	my $suffix = $self->suffix;
-	
-	if ( @_ > 0 )
-	{
-		return 0 unless defined $_[0];
-		return $_[0] eq $suffix;
-	}
-	
-	return $suffix ne '';
+    my $self = shift;
+    my $suffix = $self->suffix;
+    
+    if ( @_ > 0 )
+    {
+        return 0 unless defined $_[0];
+        return $_[0] eq $suffix;
+    }
+    
+    return $suffix ne '';
 }
 
 =item C<parent_path()>
@@ -206,9 +207,9 @@ Returns the path of the containing directory.
 
 sub parent_path
 {
-	my $self = shift;
-	
-	return $self->{PARENT_PATH};
+    my $self = shift;
+    
+    return $self->{PARENT_PATH};
 }
 
 =item C<stat()>
@@ -220,9 +221,9 @@ about the path.
 
 sub stat
 {
-	my $self = shift;
-	
-	return File::stat::stat($self->path);
+    my $self = shift;
+    
+    return File::stat::stat($self->path);
 }
 
 =item C<delete()>
@@ -233,11 +234,11 @@ Removes the instance from the cache, and undefines it.
 
 sub delete
 {
-	# Use $_[0] so that we can undef the instance.
+    # Use $_[0] so that we can undef the instance.
 
-	delete($instance_for_path{$_[0]->path});
-	
-	undef $_[0];
+    delete($instance_for_path{$_[0]->path});
+    
+    undef $_[0];
 }
 
 =back
@@ -254,4 +255,4 @@ sub delete
 
 =cut
 
-1;
\ No newline at end of file
+1;
