@@ -190,17 +190,16 @@ sub _generate_pir_for {
             load_bytecode "PGE.pbc"
             load_bytecode "PGE/Dumper.pir"
             load_bytecode "PGE/Text.pir"
-            p6rule_compile = compreg "PGE::P6Rule"
+            load_bytecode "PGE/Util.pir"
+            p6rule_compile = compreg "PGE::P6Regex"
 
             .local string target
             .local string pattern
             .local pmc rulesub
             .local pmc match
-            .local pmc code
-            .local pmc exp
             target = $unicode"$target"
             pattern = "$pattern"
-            (rulesub, code, exp) = p6rule_compile(pattern)
+            rulesub = p6rule_compile(pattern)
             if_null rulesub, rule_fail
             match = rulesub(target)
             unless match goto match_fail
@@ -226,7 +225,7 @@ sub _generate_subrule_pir {
         .sub _PGE_Test
             .local pmc p6rule_compile
             load_bytecode "PGE.pbc"
-            p6rule_compile = compreg "PGE::P6Rule"
+            p6rule_compile = compreg "PGE::P6Regex"
 
             .local string target
             .local pmc rulesub
