@@ -1,6 +1,6 @@
 /*
 Copyright: 2003-2006 The Perl Foundation.  All Rights Reserved.
-$Id: builtin.c 12055 2006-03-28 03:34:43Z jisom $
+$Id: builtin.c 12592 2006-05-10 04:55:00Z petdance $
 
 =head1 NAME
 
@@ -19,6 +19,7 @@ src/builtin.c - Builtin Methods
 */
 
 #include "parrot/parrot.h"
+#include "parrot/compiler.h"
 #include "builtin.str"
 #include <assert.h>
 
@@ -31,6 +32,7 @@ typedef struct _builtin {
     STRING *namespace;          /* same */
 } Builtins;
 
+#define N_BUILTINS (int)(sizeof(builtins) / sizeof(builtins[0]))
 static Builtins builtins[] = {
     { "acos",   "PJO",          "Float",        0, 0 },
     { "asec",   "PJO",          "Float",        0, 0 },
@@ -95,12 +97,11 @@ Return the NCI PMC of the builtin or NULL.
 void
 Parrot_init_builtins(Interp *interpreter)
 {
-    size_t i, n;
+    size_t i;
     char buffer[128];
 
-    n = sizeof(builtins) / sizeof(builtins[0]);
     buffer[0] = buffer[1] = '_';
-    for (i = 0; i < n; ++i) {
+    for (i = 0; i < N_BUILTINS; ++i) {
         /* XXX mangle yes or no */
 #ifdef MANGLE_BUILTINS
         strcpy(buffer + 2, builtins[i].c_name);
@@ -117,14 +118,20 @@ Parrot_init_builtins(Interp *interpreter)
      */
 }
 
+static int find_builtin(Interp *interpreter, const char *func)
+    __attribute__nonnull__(2);
+static int find_builtin_s(Interp *interpreter, STRING *func)
+    __attribute__nonnull__(2);
+static int check_builtin_sig(Interp *interpreter, size_t i, const char *sig, int pass)
+    __attribute__nonnull__(3);
+
 static int
-find_builtin(Interp *interpreter, char *func)
+find_builtin(Interp *interpreter, const char *func /*NN*/)
 {
-    size_t i, n;
+    size_t i;
 
-    n = sizeof(builtins) / sizeof(builtins[0]);
     /* TODO either hash or use binsearch */
-    for (i = 0; i < n; ++i) {
+    for (i = 0; i < N_BUILTINS; ++i) {
         if (strcmp(func, builtins[i].c_name) == 0)
             return i;
     }
@@ -132,13 +139,12 @@ find_builtin(Interp *interpreter, char *func)
 }
 
 static int
-find_builtin_s(Interp *interpreter, STRING *func)
+find_builtin_s(Interp *interpreter, STRING *func /*NN*/)
 {
-    size_t i, n;
+    size_t i;
 
-    n = sizeof(builtins) / sizeof(builtins[0]);
     /* TODO either hash or use binsearch */
-    for (i = 0; i < n; ++i) {
+    for (i = 0; i < N_BUILTINS; ++i) {
         if (string_equal(interpreter, func, builtins[i].meth_name) == 0)
             return i;
     }
@@ -146,9 +152,9 @@ find_builtin_s(Interp *interpreter, STRING *func)
 }
 
 static int
-check_builtin_sig(Interp *interpreter, size_t i, char *sig, int pass)
+check_builtin_sig(Interp *interpreter, size_t i, const char *sig /*NN*/, int pass)
 {
-    Builtins *b = builtins + i;
+    const Builtins * const b = builtins + i;
     const char *p;
     int opt = 0;
 
@@ -178,23 +184,22 @@ check_builtin_sig(Interp *interpreter, size_t i, char *sig, int pass)
 }
 
 int
-Parrot_is_builtin(Interp *interpreter, char *func, char *sig)
+Parrot_is_builtin(Interp *interpreter, const char *func, const char *sig)
 {
-    int bi, i, n, pass;
+    int bi, i, pass;
 
     i = find_builtin(interpreter, func);
     if (i < 0)
         return -1;
     if (!sig)
         return i;
-    n = sizeof(builtins) / sizeof(builtins[0]);
     bi = i;
     for (pass = 0; pass <= 1; ++pass) {
         i = bi;
 again:
         if (check_builtin_sig(interpreter, i, sig, pass)) 
             return i;
-        if (i < n - 1) {
+        if (i < N_BUILTINS - 1) {
             /* try next with same name */
             ++i;
             if (strcmp(func, builtins[i].c_name))
@@ -208,48 +213,36 @@ again:
 PMC*
 Parrot_find_builtin(Interp *interpreter, STRING *func)
 {
-    int i;
-    PMC *m;
-    STRING *ns;
+    const int i = find_builtin_s(interpreter, func);
 
-    i = find_builtin_s(interpreter, func);
     if (i < 0) {
-        ns = CONST_STRING(interpreter, "__parrot_core");
+        STRING * const ns = CONST_STRING(interpreter, "__parrot_core");
         return Parrot_find_global(interpreter, ns, func);
     }
-    m = Parrot_find_global(interpreter,
+    return
+        Parrot_find_global(interpreter,
             builtins[i].namespace,
             builtins[i].meth_name);
-    return m;
 }
 
 const char *
 Parrot_builtin_get_c_namespace(Interp *interpreter, int bi)
 {
-    int n;
-
-    n = sizeof(builtins) / sizeof(builtins[0]);
-    assert(bi >= 0 && bi < n);
+    assert(bi >= 0 && bi < N_BUILTINS);
     return builtins[bi].c_ns;
 }
 
 int
 Parrot_builtin_is_class_method(Interp *interpreter, int bi)
 {
-    int n;
-
-    n = sizeof(builtins) / sizeof(builtins[0]);
-    assert(bi >= 0 && bi < n);
+    assert(bi >= 0 && bi < N_BUILTINS);
     return builtins[bi].signature[2] != 'O';
 }
 
 int
 Parrot_builtin_is_void(Interp *interpreter, int bi)
 {
-    int n;
-
-    n = sizeof(builtins) / sizeof(builtins[0]);
-    assert(bi >= 0 && bi < n);
+    assert(bi >= 0 && bi < N_BUILTINS);
     return builtins[bi].signature[0] == 'v';
 }
 
