@@ -1,6 +1,6 @@
 /*
 Copyright: 2001-2006 The Perl Foundation.  All Rights Reserved.
-$Id: exec.c 12076 2006-03-29 22:22:22Z bernhard $
+$Id: exec.c 12592 2006-05-10 04:55:00Z petdance $
 
 =head1 NAME
 
@@ -24,8 +24,9 @@ src/exec.c - Generate an object file
 #include "parrot/jit.h"
 #define JIT_EMIT 1
 #include "parrot/jit_emit.h"
-#include "parrot/exec_dep.h"
-#include "parrot/exec_save.h"
+#include "exec_dep.h"
+#include "exec_save.h"
+#include "parrot/compiler.h"
 
 static void exec_init(Parrot_exec_objfile_t *obj);
 static void add_data_member(Parrot_exec_objfile_t *obj, void *src, size_t len);
@@ -65,12 +66,11 @@ Parrot_exec(Interp *interpreter, opcode_t *pc,
 #endif
     const char *output;
     long bhs;
-    Parrot_exec_objfile_t *obj;
     Parrot_jit_info_t *jit_info;
-    extern char **Parrot_exec_rel_addr;
-    extern int Parrot_exec_rel_count;
+    extern PARROT_API char **Parrot_exec_rel_addr;
+    extern PARROT_API int Parrot_exec_rel_count;
 
-    obj = mem_sys_allocate_zeroed(sizeof(Parrot_exec_objfile_t));
+    Parrot_exec_objfile_t * const obj = mem_sys_allocate_zeroed(sizeof(Parrot_exec_objfile_t));
     exec_init(obj);
     Parrot_exec_rel_addr = (char **)mem_sys_allocate_zeroed(4 * sizeof(char *));
     obj->bytecode_header_size =
@@ -129,6 +129,10 @@ C<< obj->data_size[N] >>.
 
 */
 
+static void
+add_data_member(Parrot_exec_objfile_t *obj, void *src, size_t len)
+                __attribute__nonnull__(1);
+
 static void
 add_data_member(Parrot_exec_objfile_t *obj, void *src, size_t len)
 {
@@ -140,8 +144,7 @@ add_data_member(Parrot_exec_objfile_t *obj, void *src, size_t len)
         obj->data_size = (int *)mem_sys_allocate(sizeof(int));
     }
     else {
-        cp = (char *)mem_sys_realloc(obj->data.code, obj->data.size + len);
-        obj->data.code = cp;
+        obj->data.code = (char *)mem_sys_realloc(obj->data.code, obj->data.size + len);
         nds = (int *)mem_sys_realloc(obj->data_size, (obj->data_count + 2) *
             sizeof(int));
         obj->data_size = nds;
@@ -167,6 +170,9 @@ Initialize the obj structure.
 
 */
 
+static void exec_init(Parrot_exec_objfile_t *obj)
+    __attribute__nonnull__(1);
+
 static void
 exec_init(Parrot_exec_objfile_t *obj)
 {
@@ -211,11 +217,11 @@ int
 Parrot_exec_add_symbol(Parrot_exec_objfile_t *obj, const char *symbol,
     int stype)
 {
-    int symbol_number;
-    Parrot_exec_symbol_t *new_symbol;
 
-    symbol_number = symbol_list_find(obj, symbol);
+    int symbol_number = symbol_list_find(obj, symbol);
     if (symbol_number == -1) {
+        Parrot_exec_symbol_t *new_symbol;
+
         symbol_number = obj->symbol_count;
         new_symbol = mem_sys_realloc(obj->symbol_table,
             (size_t)(obj->symbol_count + 1) * sizeof(Parrot_exec_symbol_t));
@@ -297,8 +303,8 @@ Parrot_exec_add_text_rellocation(Parrot_exec_objfile_t *obj, char *nptr,
     int symbol_number = 0;
     char *addr;
     Parrot_exec_rellocation_t *new_relloc;
-    extern char **Parrot_exec_rel_addr;
-    extern int Parrot_exec_rel_count;
+    extern PARROT_API char **Parrot_exec_rel_addr;
+    extern PARROT_API int Parrot_exec_rel_count;
 
     new_relloc = mem_sys_realloc(obj->text_rellocation_table,
         (size_t)(obj->text_rellocation_count + 1)
@@ -342,6 +348,11 @@ Used by C<Parrot_exec_add_symbol()>.
 
 */
 
+static int
+symbol_list_find(Parrot_exec_objfile_t *obj, const char *symbol)
+    __attribute__nonnull__(1)
+    __attribute__nonnull__(2);
+
 static int
 symbol_list_find(Parrot_exec_objfile_t *obj, const char *symbol)
 {
@@ -359,7 +370,7 @@ symbol_list_find(Parrot_exec_objfile_t *obj, const char *symbol)
 
 =head1 SEE ALSO
 
-F<include/parrot/exec.h>, F<src/exec_cpu.c>, F<include/parrot/exec_save.h>
+F<include/parrot/exec.h>, F<src/exec_cpu.c>, F<src/exec_save.h>
 and F<src/exec_start.c>.
 
 =head1 HISTORY
