@@ -1,6 +1,6 @@
 /*
-Copyright: 2001-2003 The Perl Foundation.  All Rights Reserved.
-$Id: io_private.h 11622 2006-02-17 11:39:36Z leo $
+Copyright: 2001-2006 The Perl Foundation.  All Rights Reserved.
+$Id: io_private.h 11750 2006-02-26 14:40:58Z bernhard $
 
 =head1 NAME
 
@@ -273,6 +273,13 @@ ParrotIOLayer * PIO_mmap_register_layer(void);
 void PIO_push_layer_str(Interp *interpreter, PMC *pmc, STRING *ls);
 STRING* PIO_pop_layer_str(Interp *interpreter, PMC *pmc);
 
+/* Parrot_Socklen_t is used in POSIX accept call */
+#if PARROT_HAS_SOCKLEN_T
+typedef socklen_t Parrot_Socklen_t;
+#else
+typedef int Parrot_Socklen_t;
+#endif
+
 #endif /* PARROT_IO_PRIVATE_H_GUARD */
 
 /*
