@@ -1,6 +1,6 @@
 /*
 Copyright: 2001-2003 The Perl Foundation.  All Rights Reserved.
-$Id: jit_debug.c 10754 2005-12-29 01:19:55Z particle $
+$Id: jit_debug.c 11975 2006-03-21 22:23:53Z bernhard $
 
 =head1 NAME
 
@@ -92,7 +92,7 @@ typedef struct {
 
 /*
 
-=item C<static void write_types(FILE *stabs)>
+=item C<static void write_types(FILE *stabs, Interp *interpreter)>
 
 Writes the types to C<stabs>.
 
@@ -101,7 +101,7 @@ Writes the types to C<stabs>.
 */
 
 static void
-write_types(FILE *stabs)
+write_types(FILE *stabs, Interp *interpreter)
 {
     int i, j;
     /* borrowed from mono */
@@ -163,9 +163,9 @@ write_types(FILE *stabs)
                 );
 
     fprintf(stabs, ".stabs \"PMCType:T(0,%d)=e", i++);
-    for (j = 0; j < enum_class_max; ++j) {
-        if (Parrot_base_vtables[j] && Parrot_base_vtables[j]->whoami) {
-            STRING* name = Parrot_base_vtables[j]->whoami;
+    for (j = 0; j < interpreter->n_vtable_max; ++j) {
+        if (interpreter->vtables[j] && interpreter->vtables[j]->whoami) {
+            STRING* name = interpreter->vtables[j]->whoami;
             fwrite(name->strstart, name->strlen, 1, stabs);
             fprintf(stabs, ":%d,", j);
         }
@@ -333,7 +333,7 @@ Parrot_jit_debug_stabs(Interp *interpreter)
     fprintf(stabs, ".stabs \"jit_func:F(0,1)\"," N_FUN ",0,1,%p\n",
             jit_info->arena.start);
 
-    write_types(stabs);
+    write_types(stabs, interpreter);
     write_vars(stabs, interpreter);
     /* if we don't have line numbers, emit dummys, assuming there are
      * no comments and spaces in source for testing
