@@ -1,6 +1,6 @@
 /*
-Copyright: 2003 The Perl Foundation.  All Rights Reserved.
-$Id: mmd.c 12064 2006-03-28 19:08:48Z bernhard $
+Copyright: 2003-2006 The Perl Foundation.  All Rights Reserved.
+$Id: mmd.c 12540 2006-05-07 04:27:54Z petdance $
 
 =head1 NAME
 
@@ -56,7 +56,7 @@ dump_mmd(Interp *interpreter, INTVAL function)
 {
     UINTVAL x, y;
     UINTVAL offset, x_funcs, y_funcs;
-    MMD_table *table = interpreter->binop_mmd_funcs + function;
+    MMD_table * const table = interpreter->binop_mmd_funcs + function;
     funcptr_t func, def;
 
     x_funcs = table->x;
@@ -99,6 +99,10 @@ dump_mmd(Interp *interpreter, INTVAL function)
 
 extern void Parrot_deleg_pmc_mark(Interp*, PMC* pmc);
 
+static int
+isa_deleg_pmc(Interp *interpreter, PMC *p)
+                __attribute__nonnull__(2);
+
 static int
 isa_deleg_pmc(Interp *interpreter, PMC *p)
 {
@@ -367,16 +371,14 @@ PMC*
 mmd_dispatch_p_pip(Interp *interpreter,
 		 PMC *left, INTVAL right, PMC *dest, INTVAL func_nr)
 {
-    mmd_f_p_pip real_function;
-    PMC *sub;
     int is_pmc;
-    UINTVAL left_type;
 
-    left_type = left->vtable->base_type;
-    real_function = (mmd_f_p_pip)get_mmd_dispatch_type(interpreter,
-            func_nr, left_type, enum_type_INTVAL, &is_pmc);
+    const UINTVAL left_type = left->vtable->base_type;
+    const mmd_f_p_pip real_function =
+        (mmd_f_p_pip)get_mmd_dispatch_type(interpreter, func_nr, left_type, enum_type_INTVAL, &is_pmc);
+
     if (is_pmc) {
-        sub = (PMC*)real_function;
+        PMC * const sub = (PMC*)real_function;
         if (is_pmc == 2) {
             /* mmd_register the wrapper */
             mmd_register(interpreter, func_nr, left->vtable->base_type,
@@ -2013,7 +2015,7 @@ mmd_create_ns(Interp *interpreter)
     ns_name = CONST_STRING(interpreter, "__parrot_core");
     ns = VTABLE_get_pmc_keyed_str(interpreter, 
             interpreter->stash_hash, ns_name);
-    if (!ns) {
+    if (PMC_IS_NULL(ns)) {
         ns = pmc_new(interpreter, enum_class_NameSpace);
         VTABLE_set_pmc_keyed_str(interpreter, 
                 interpreter->stash_hash, ns_name, ns);
