@@ -1,6 +1,6 @@
 /*
 Copyright: 2006 The Perl Foundation.  All Rights Reserved.
-$Id: pic_jit.c 11746 2006-02-26 13:08:48Z leo $
+$Id: pic_jit.c 12588 2006-05-10 03:06:58Z petdance $
 
 =head1 NAME
 
@@ -67,29 +67,20 @@ TODO:
 static opcode_t *
 pic_test_func(Interp *interpreter, INTVAL *sig_bits, void **args)
 {
-    opcode_t *pc;
-    INTVAL *result, i, j;
-
-    result = (INTVAL*) args[0];
-    i = (INTVAL) args[1];
-    j = (INTVAL) args[2];
+    INTVAL * const result = (INTVAL*) args[0];
+    const INTVAL i = (INTVAL) args[1];
+    const INTVAL j = (INTVAL) args[2];
     *result = i + j;
-    pc = args[3];
-    return pc;
+    return args[3];
 }
 #endif
 
 static int
 jit_can_compile_sub(Interp *interpreter, PMC *sub)
 {
-    const jit_arch_info *info;
-    const jit_arch_regs *regs;
-    INTVAL *n_regs_used;
-          
-    info = Parrot_jit_init(interpreter);
-
-    regs = info->regs + JIT_CODE_SUB_REGS_ONLY;
-    n_regs_used = PMC_sub(sub)->n_regs_used;
+    const jit_arch_info * const info = Parrot_jit_init(interpreter);
+    const jit_arch_regs * const regs = info->regs + JIT_CODE_SUB_REGS_ONLY;
+    INTVAL * const n_regs_used = PMC_sub(sub)->n_regs_used;
 
     /* if the sub is using more regs than the arch has
      * we don't JIT it at all
@@ -147,9 +138,9 @@ args_match_params(Interp *interpreter, PMC *sig_args,
 static int
 returns_match_results(Interp *interpreter, PMC *sig_ret, PMC *sig_result)
 {
-    int n, type;
-    
-    n = parrot_pic_check_sig(interpreter, sig_ret, sig_result, &type);
+    int type;
+
+    const int n = parrot_pic_check_sig(interpreter, sig_ret, sig_result, &type);
     if (n == -1) {
         /* arg count mismatch */
         return 0;
@@ -173,11 +164,11 @@ returns_match_results(Interp *interpreter, PMC *sig_ret, PMC *sig_result)
 static int
 call_is_safe(Interp *interpreter, PMC *sub, opcode_t **set_args)
 {
-    opcode_t *pc;
-    PMC *sig_args, *called, *sig_results;
+    PMC *called, *sig_results;
+
+    opcode_t * pc = *set_args;
+    PMC * const sig_args = PMC_sub(sub)->seg->const_table->constants[pc[1]]->u.key;
 
-    pc = *set_args;
-    sig_args = PMC_sub(sub)->seg->const_table->constants[pc[1]]->u.key;
     /* ignore the signature for now */
     pc += 2 + SIG_ELEMS(sig_args);
     if (*pc != PARROT_OP_set_p_pc)
@@ -204,18 +195,15 @@ ops_jittable(Interp *interpreter, PMC *sub, PMC *sig_results,
         struct PackFile_ByteCode *seg,
         opcode_t *pc, opcode_t *end, int *flags)
 {
-    op_info_t *op_info;
-    int i, n, op;
-    PMC *sig_ret;
-
     while (pc < end) {
-        op = *pc;
         /*
          * some special opcodes, which are handled, but not marked
          * as JITtable
          */
-        op_info = interpreter->op_info_table + op;
-        n = op_info->op_count;
+        const int op = *pc;
+        op_info_t * const op_info = interpreter->op_info_table + op;
+        int n = op_info->op_count;
+        int i;
 
         switch (op) {
             case PARROT_OP_returncc:
@@ -223,9 +211,11 @@ ops_jittable(Interp *interpreter, PMC *sub, PMC *sig_results,
                 goto op_is_ok;
                 break;
             case PARROT_OP_set_returns_pc:
-                sig_ret = seg->const_table->constants[pc[1]]->u.key;
+                {
+                PMC * const sig_ret = seg->const_table->constants[pc[1]]->u.key;
                 if (!returns_match_results(interpreter, sig_ret, sig_results))
                     return 0;
+                }
                 goto op_is_ok;
                 break;
             case PARROT_OP_set_args_pc:
@@ -246,10 +236,7 @@ ops_jittable(Interp *interpreter, PMC *sub, PMC *sig_results,
          * handle (yet)
          */
         for (i = 1; i < n; i++) {
-            opcode_t arg = pc[i];
-            int type;
-
-            type = op_info->types[i - 1];
+            const int type = op_info->types[i - 1];
             switch (type) {
                 case PARROT_ARG_I:
                 case PARROT_ARG_N:
@@ -271,13 +258,11 @@ int
 parrot_pic_is_safe_to_jit(Interp *interpreter, PMC *sub,
 	PMC *sig_args, PMC *sig_results, int *flags)
 {
-    STRING *name;
 
     opcode_t *base, *start, *end;
+    STRING * const name = VTABLE_get_string(interpreter, sub);
 
     *flags = 0;
-    /* simplify debugging */
-    name = VTABLE_get_string(interpreter, sub);
 
     /*
      * 0) if runcore setting doesn't contain JIT
@@ -313,8 +298,9 @@ parrot_pic_is_safe_to_jit(Interp *interpreter, PMC *sub,
     return 1;
 }
 
-funcptr_t 
-parrot_pic_JIT_sub(Interp *interpreter, PMC *sub, int flags) {
+funcptr_t
+parrot_pic_JIT_sub(Interp *interpreter, PMC *sub, int flags)
+{
 #if PIC_TEST
     UNUSED(interpreter);
     UNUSED(sub);
@@ -323,15 +309,12 @@ parrot_pic_JIT_sub(Interp *interpreter, PMC *sub, int flags) {
     /*
      * create JIT code - just a test
      */
-    Parrot_jit_info_t *jit_info;
-    opcode_t *base, *start, *end;
-
-    base = PMC_sub(sub)->seg->base.data;
-    start = base + PMC_sub(sub)->start_offs;
-    end   = base + PMC_sub(sub)->end_offs;
+    opcode_t * const base =  PMC_sub(sub)->seg->base.data;
+    opcode_t * const start = base + PMC_sub(sub)->start_offs;
+    opcode_t * const end   = base + PMC_sub(sub)->end_offs;
     /* TODO pass Sub */
 
-    jit_info = parrot_build_asm(interpreter, start, end, NULL,
+    Parrot_jit_info_t * jit_info = parrot_build_asm(interpreter, start, end, NULL,
             JIT_CODE_SUB_REGS_ONLY | flags);
     if (!jit_info)
         return NULLfunc;
