@@ -1,6 +1,6 @@
 /*
 Copyright: 2001-2004 The Perl Foundation.  All Rights Reserved.
-$Id: stack_common.c 9260 2005-09-28 16:00:42Z robert $
+$Id: stack_common.c 12552 2006-05-07 16:24:26Z petdance $
 
 =head1 NAME
 
@@ -54,7 +54,7 @@ debugging/error reporting.
 */
 
 Stack_Chunk_t *
-register_new_stack(Interp *interpreter, const char *name, size_t item_size)
+register_new_stack(Interp *interpreter, const char *name /*NN*/, size_t item_size)
 {
     Stack_Chunk_t *chunk;
 
@@ -73,7 +73,7 @@ register_new_stack(Interp *interpreter, const char *name, size_t item_size)
 /*
 
 =item C<Stack_Chunk_t *
-cst_new_stack_chunk(Interp *interpreter, Stack_Chunk_t *)>
+cst_new_stack_chunk(Interp *interpreter, const Stack_Chunk_t *chunk)>
 
 Get a new chunk either from the freelist or allocate one.
 
@@ -82,14 +82,11 @@ Get a new chunk either from the freelist or allocate one.
 */
 
 Stack_Chunk_t *
-cst_new_stack_chunk(Parrot_Interp interpreter, Stack_Chunk_t *chunk)
+cst_new_stack_chunk(Parrot_Interp interpreter, const Stack_Chunk_t *chunk /*NN*/)
 {
-    Stack_Chunk_t *new_chunk;
+    struct Small_Object_Pool * const pool = get_bufferlike_pool(interpreter, chunk->size);
+    Stack_Chunk_t * const new_chunk = pool->get_free_object(interpreter, pool);
 
-    struct Small_Object_Pool *pool;
-
-    pool = get_bufferlike_pool(interpreter, chunk->size);
-    new_chunk = pool->get_free_object(interpreter, pool);
     PObj_bufstart(new_chunk) = NULL;
     PObj_buflen  (new_chunk) = 0;
 
@@ -110,11 +107,11 @@ Return a pointer, where new entries go for push.
 */
 
 void*
-stack_prepare_push(Parrot_Interp interpreter, Stack_Chunk_t **stack_p)
+stack_prepare_push(Parrot_Interp interpreter, Stack_Chunk_t **stack_p /*NN*/)
 {
-    Stack_Chunk_t *chunk = *stack_p, *new_chunk;
+    Stack_Chunk_t * const chunk = *stack_p;
+    Stack_Chunk_t * const new_chunk = cst_new_stack_chunk(interpreter, chunk);
 
-    new_chunk = cst_new_stack_chunk(interpreter, chunk);
     new_chunk->prev = chunk;
     *stack_p = new_chunk;
     return STACK_DATAP(new_chunk);
@@ -133,9 +130,9 @@ Return a pointer, where new entries are poped off.
 */
 
 void*
-stack_prepare_pop(Parrot_Interp interpreter, Stack_Chunk_t **stack_p)
+stack_prepare_pop(Parrot_Interp interpreter, Stack_Chunk_t **stack_p /*NN*/)
 {
-    Stack_Chunk_t *chunk = *stack_p;
+    Stack_Chunk_t * const chunk = *stack_p;
     /*
      * the first entry (initial top) refers to itself
      */
