@@ -1,6 +1,6 @@
 /*
-Copyright: 2001-2005 The Perl Foundation.  All Rights Reserved.
-$Id: string.c 12070 2006-03-29 12:37:38Z leo $
+Copyright: 2001-2006 The Perl Foundation.  All Rights Reserved.
+$Id: string.c 12590 2006-05-10 03:23:37Z autrijus $
 
 =head1 NAME
 
@@ -21,6 +21,8 @@ strings.
 */
 
 #include "parrot/parrot.h"
+#include "parrot/compiler.h"
+#include "parrot/string_private_cstring.h"
 #include <assert.h>
 
 /*
@@ -46,23 +48,14 @@ strings.
 
 /*
 
-
-=head2 String COW support
-
-=over 4
-
-=item C<static void
-Parrot_unmake_COW(Interp *interpreter, STRING *s)>
-
+FUNCDOC:
 If the specified Parrot string is copy-on-write then the memory is
 copied over and the copy-on-write flag is cleared.
 
-=cut
-
 */
 
 void
-Parrot_unmake_COW(Interp *interpreter, STRING *s)
+Parrot_unmake_COW(Interp *interpreter, STRING *s /*NN*/)
 {
     /* COW_FLAG | constant_FLAG | external_FLAG) */
     if (PObj_is_cowed_TESTALL(s)) {
@@ -97,31 +90,23 @@ Parrot_unmake_COW(Interp *interpreter, STRING *s)
 
 /*
 
-=item C<static void
-copy_string_header(Interp *interpreter, String *dest, String *src)>
-
+FUNCDOC:
 Copies the string header from the first Parrot string to the second.
 
-=cut
-
 */
 
 static void
-copy_string_header(Interp *interpreter, String *dest, String *src)
+copy_string_header(String *dest /*NN*/, const String *src /*NN*/)
 {
     memcpy(dest, src, sizeof(String));
 }
 
 /*
 
-=item C<static STRING *
-Parrot_make_COW_reference(Interp *interpreter, STRING *s)>
-
+FUNCDOC:
 Creates a copy-on-write string by cloning a string header without
 allocating a new buffer.
 
-=cut
-
 */
 
 STRING *
@@ -134,7 +119,7 @@ Parrot_make_COW_reference(Interp *interpreter, STRING *s)
     if (PObj_constant_TEST(s)) {
         d = new_string_header(interpreter, 0);
         PObj_COW_SET(s);
-        copy_string_header(interpreter, d, s);
+        copy_string_header(d, s);
         /* we can't move the memory, because constants aren't
          * scanned in compact_pool, therefore the other end
          * would point to garbage.
@@ -144,39 +129,35 @@ Parrot_make_COW_reference(Interp *interpreter, STRING *s)
     else {
         d = new_string_header(interpreter, PObj_get_FLAGS(s));
         PObj_COW_SET(s);
-        copy_string_header(interpreter, d, s);
+        copy_string_header(d, s);
         PObj_sysmem_CLEAR(d);
     }
     return d;
 }
 /*
 
-=item C<static STRING *
-Parrot_reuse_COW_reference(Interp *interpreter, STRING *s, STRING *reuse)>
-
+FUNCDOC:
 Creates a copy-on-write string by cloning a string header without
 allocating a new buffer. Doesn't allocate a new string header, instead
 using the one passed in and returns it.
 
-=cut
-
 */
 
 STRING*
-Parrot_reuse_COW_reference(Interp *interpreter, STRING *s, STRING *d)
+Parrot_reuse_COW_reference(Interp *interpreter, STRING *s, STRING *d /*NN*/)
 {
     if (s == NULL) {
         return NULL;
     }
     if (PObj_constant_TEST(s)) {
         PObj_COW_SET(s);
-        copy_string_header(interpreter, d, s);
+        copy_string_header(d, s);
         PObj_constant_CLEAR(d);
         PObj_external_SET(d);
     }
     else {
         PObj_COW_SET(s);
-        copy_string_header(interpreter, d, s);
+        copy_string_header(d, s);
         PObj_sysmem_CLEAR(d);
     }
     return d;
@@ -184,18 +165,14 @@ Parrot_reuse_COW_reference(Interp *interpreter, STRING *s, STRING *d)
 
 /*
 
-=item C<STRING *
-string_set(Interp *interpreter, STRING *dest, STRING *src)>
-
+FUNCDOC:
 Makes the contents of first Parrot string a copy of the contents of
 second.
 
-=cut
-
 */
 
 STRING *
-string_set(Interp *interpreter, STRING *dest, STRING *src)
+string_set(Interp *interpreter, STRING *dest /*NN*/, STRING *src)
 {
     if (!src)
         return NULL;
@@ -218,30 +195,15 @@ string_set(Interp *interpreter, STRING *dest, STRING *src)
 
 /*
 
-=back
-
 =head2 Basic String Functions
 
 Creation, enlargement, etc.
 
-=over 4
-
-=item C<void
-string_init(Interp*)>
-
+FUNCDOC:
 Initializes the Parrot string subsystem.
 
-=item C<void
-string_deinit(Interp*)>
-
-De-Initializes the Parrot string subsystem.
-
-=cut
-
 */
 
-#include "parrot/string_private_cstring.h"
-
 void
 string_init(Parrot_Interp interpreter)
 {
@@ -284,6 +246,13 @@ string_init(Parrot_Interp interpreter)
 
 }
 
+/*
+
+FUNCDOC:
+De-Initializes the Parrot string subsystem.
+
+*/
+
 void
 string_deinit(Parrot_Interp interpreter)
 {
@@ -297,18 +266,14 @@ string_deinit(Parrot_Interp interpreter)
 
 /*
 
-=item C<UINTVAL
-string_capacity(Interp *interpreter, STRING *s)>
-
+FUNCDOC:
 Returns the capacity of the specified Parrot string in bytes, that
 is how many bytes can be appended onto strstart.
 
-=cut
-
 */
 
 UINTVAL
-string_capacity(Interp *interpreter, STRING *s)
+string_capacity(Interp *interpreter, const STRING *s /*NN*/)
 {
     return ((ptrcast_t)PObj_bufstart(s) + PObj_buflen(s) -
             (ptrcast_t)s->strstart);
@@ -316,23 +281,16 @@ string_capacity(Interp *interpreter, STRING *s)
 
 /*
 
-=item C<STRING *
-string_make_empty(Interp *interpreter,
-    parrot_string_representation_t representation, UINTVAL capacity)>
-
+FUNCDOC:
 Creates and returns an empty Parrot string.
 
-=cut
-
 */
 
 STRING *
 string_make_empty(Interp *interpreter,
     parrot_string_representation_t representation, UINTVAL capacity)
 {
-    STRING *s;
-
-    s = new_string_header(interpreter, 0);
+    STRING * const s = new_string_header(interpreter, 0);
 
     /*
      * TODO adapt string creation functions
@@ -352,9 +310,7 @@ string_make_empty(Interp *interpreter,
 
 /*
 
-=item C<CHARSET *string_rep_compatible (Interp *, STRING *a, const STRING *b,
-        ENCODING **e)>
-
+FUNCDOC:
 Find the "lowest" possible charset and encoding for the given string. E.g.
 
   ascii <op> utf8 => utf8
@@ -362,19 +318,17 @@ Find the "lowest" possible charset and encoding for the given string. E.g.
 
 Returs NULL, if no compatible string representation can be found.
 
-=cut
-
 */
 
 CHARSET *
-string_rep_compatible (Interp *interpreter, STRING *a, const STRING *b,
-        ENCODING **e)
+string_rep_compatible (Interp *interpreter, STRING *a /*NN*/, const STRING *b /*NN*/,
+        ENCODING **e /*NN*/)
 {
     if (a->encoding == b->encoding && a->charset == b->charset) {
         *e = a->encoding;
         return a->charset;
     }
-            
+
     /*
      * a table could possibly simplify the logic
      */
@@ -416,28 +370,21 @@ string_rep_compatible (Interp *interpreter, STRING *a, const STRING *b,
 
 /*
 
-=item C<STRING *
-string_append(Interp *interpreter,
-    STRING *a, STRING *b, UINTVAL Uflags)>
-
+FUNCDOC:
 Take in two Parrot strings and append the second to the first.
 
-=cut
-
 */
 
 STRING *
 string_append(Interp *interpreter,
-    STRING *a, STRING *b, UINTVAL Uflags)
+    STRING *a, STRING *b /*NN*/, UINTVAL Uflags)
 {
     UINTVAL a_capacity, b_len;
     UINTVAL total_length;
     CHARSET *cs;
     ENCODING *enc;
 
-    /*
-     * XXX should this be a CHARSET method?
-     */
+    /* XXX should this be a CHARSET method? */
 
     UNUSED(Uflags);
 
@@ -502,15 +449,9 @@ string_append(Interp *interpreter,
 
 /*
 
-=item C<
-STRING *
-string_from_cstring(Interp *interpreter,
-    const void *buffer, UINTVAL len)>
-
+FUNCDOC:
 Make a Parrot string from a specified C string.
 
-=cut
-
 */
 
 STRING *
@@ -526,15 +467,9 @@ string_from_cstring(Interp *interpreter,
 
 /*
 
-=item C<
-STRING *
-string_from_const_cstring(Interp *interpreter,
-    const void *buffer, UINTVAL len)>
-
+FUNCDOC:
 Make a Parrot string from a specified C string.
 
-=cut
-
 */
 
 STRING *
@@ -549,17 +484,12 @@ string_from_const_cstring(Interp *interpreter,
 
 /*
 
-=item C<const char*
-string_primary_encoding_for_representation(Interp *interpreter,
-    parrot_string_representation_t representation)>
-
+FUNCDOC:
 Returns the primary encoding for the specified representation.
 
 This is needed for packfile unpacking, unless we just always use UTF-8
 or BOCU.
 
-=cut
-
 */
 
 const char*
@@ -581,17 +511,13 @@ string_primary_encoding_for_representation(Interp *interpreter,
 
 /*
 
-=item C<STRING *
-const_string(Interp *interpreter, const char *buffer)>
-
+FUNCDOC:
 Creates and returns a constant Parrot string.
 
-=cut
-
 */
 
 STRING *
-const_string(Interp *interpreter, const char *buffer)
+const_string(Interp *interpreter, const char *buffer /*NN*/)
 {
     /* TODO cache the strings */
     return string_make_direct(interpreter, buffer, strlen(buffer),
@@ -601,9 +527,7 @@ const_string(Interp *interpreter, const char *buffer)
 
 /*
 
-=item C<STRING *
-string_make(Interp *interpreter, const void *buffer,
-    UINTVAL len, const char *charset_name, UINTVAL flags)>
+FUNCDOC:
 
 Creates and returns a new Parrot string using C<len> bytes of string
 data read from C<buffer>.
@@ -614,6 +538,10 @@ The currently recognised values are:
     'iso-8859-1'
     'ascii'
     'binary'
+    'unicode'
+
+The encoding is implicitly guessed; C<unicode> impliies the C<utf-8>
+encoding, and the other three assume C<fixed-8> encoding.
 
 If C<charset> is unspecified the default charset 'ascii' will be
 used.
@@ -621,8 +549,6 @@ used.
 The value of C<flags> is optionally one or more C<PObj_*> flags C<OR>-ed
 together.
 
-=cut
-
 */
 
 STRING *
@@ -650,13 +576,12 @@ STRING *
 string_make_direct(Interp *interpreter, const void *buffer,
         UINTVAL len, ENCODING *encoding, CHARSET *charset, UINTVAL flags)
 {
-    STRING *s;
     union {
         const void * __c_ptr;
         void * __ptr;
     } __ptr_u;
+    STRING * const s = new_string_header(interpreter, flags);
 
-    s = new_string_header(interpreter, flags);
     s->encoding = encoding;
     s->charset = charset;
 
@@ -699,13 +624,10 @@ string_make_direct(Interp *interpreter, const void *buffer,
 
 /*
 
-=item C<STRING *
-string_grow(Interp * interpreter, STRING * s, INTVAL addlen)>
+FUNCDOC:
 
 Grows the Parrot string's buffer by the specified number of characters.
 
-=cut
-
 */
 
 STRING *
@@ -721,19 +643,12 @@ string_grow(Interp * interpreter, STRING * s, INTVAL addlen)
 
 /*
 
-=back
-
 =head2 Ordinary user-visible string operations
 
-=over 4
-
-=item C<UINTVAL
-string_length(Interp * interpreter, const STRING *s)>
+FUNCDOC:
 
 Returns the number of characters in the specified Parrot string.
 
-=cut
-
 */
 
 UINTVAL
@@ -741,11 +656,10 @@ string_length(Interp * interpreter, const STRING *s)
 {
     return s ? s->strlen : 0;
 }
+
 /*
 
-=item C<INTVAL
-string_index(Interp * interpreter, const STRING *s, UINTVAL idx)>
-
+FUNCDOC:
 Returns the character (or glyph, depending upon the string's encoding)
 This is to abstract the process of finding the Nth character in a
 (possibly unicode or JIS-encoded) string, the idea being that once the
@@ -754,8 +668,6 @@ thing.
 
 Note that this is not range-checked.
 
-=cut
-
 */
 
 INTVAL
@@ -767,17 +679,12 @@ string_index(Interp * interpreter, const STRING *s, UINTVAL idx)
 
 /*
 
-=item C<INTVAL
-string_str_index(Interp *interpreter, const STRING *s,
-        const STRING *s2, UINTVAL start)>
-
+FUNCDOC:
 Returns the character position of the second Parrot string in the first
 at or after C<start>. The return value is a (0 based) offset in
 characters, not bytes. If second string is not specified, then return
 -1.
 
-=cut
-
 */
 
 INTVAL
@@ -812,22 +719,16 @@ string_str_index(Interp *interpreter, const STRING *s,
 
 /*
 
-=item C<INTVAL
-string_ord(Interp *interpreter, const STRING *s, INTVAL idx)>
-
+FUNCDOC:
 Returns the codepoint at a given index into a string. Negative indexes
 are treated as counting from the end of the string.
 
-=cut
-
 */
 
 INTVAL
 string_ord(Interp *interpreter, const STRING *s, INTVAL idx)
 {
-    UINTVAL len;
-
-    len = string_length(interpreter, s);
+    const UINTVAL len = string_length(interpreter, s);
 
     if (len == 0) {
         internal_exception(ORD_OUT_OF_STRING,
@@ -859,15 +760,11 @@ string_ord(Interp *interpreter, const STRING *s, INTVAL idx)
 
 /*
 
-=item C<STRING *
-string_chr(Interp *interpreter, UINTVAL character)>
-
+FUNCDOC:
 Returns a single character Parrot string.
 
 TODO - Allow this to take an array of characters?
 
-=cut
-
 */
 
 STRING *
@@ -884,13 +781,9 @@ string_chr(Interp *interpreter, UINTVAL character)
 
 /*
 
-=item C<STRING *
-string_copy(Interp *interpreter, STRING *s)>
-
+FUNCDOC:
 Creates and returns a copy of the specified Parrot string.
 
-=cut
-
 */
 
 STRING *
@@ -902,24 +795,16 @@ string_copy(Interp *interpreter, STRING *s)
 
 /*
 
-=back
-
 =head2 Vtable Dispatch Functions
 
-=over 4
-
-=item C<INTVAL
-string_compute_strlen(Interp *interpreter, STRING *s)>
-
+FUNCDOC:
 Calculates and returns the number of characters in the specified Parrot
 string.
 
-=cut
-
 */
 
 INTVAL
-string_compute_strlen(Interp *interpreter, STRING *s)
+string_compute_strlen(Interp *interpreter, STRING *s /*NN*/)
 {
     s->strlen = CHARSET_CODEPOINTS(interpreter, s);
     return s->strlen;
@@ -927,14 +812,10 @@ string_compute_strlen(Interp *interpreter, STRING *s)
 
 /*
 
-=item C<INTVAL
-string_max_bytes(Interp *interpreter, STRING *s, INTVAL nchars)>
-
+FUNCDOC:
 Returns the number of bytes required to safely contain the specified number
 of characters in the specified Parrot string's representation.
 
-=cut
-
 */
 
 INTVAL
@@ -946,23 +827,17 @@ string_max_bytes(Interp *interpreter, STRING *s, INTVAL nchars)
 
 /*
 
-=item C<STRING *
-string_concat(Interp *interpreter,
-    STRING *a, STRING *b, UINTVAL Uflags)>
-
+FUNCDOC:
 Concatenates two Parrot string. If necessary, converts the second
 string's encoding and/or type to match those of the first string. If
 either string is C<NULL>, then a copy of the non-C<NULL> string is
 returned. If both strings are C<NULL>, then a new zero-length string is
 created and returned.
 
-=cut
-
 */
 
 STRING *
-string_concat(Interp *interpreter,
-    STRING *a, STRING *b, UINTVAL Uflags)
+string_concat(Interp *interpreter, STRING *a, STRING *b, UINTVAL Uflags)
 {
     if (a != NULL && a->strlen != 0) {
         if (b != NULL && b->strlen != 0) {
@@ -1001,26 +876,20 @@ string_concat(Interp *interpreter,
 
 /*
 
-=item C<STRING *
-string_repeat(Interp *interpreter, const STRING *s,
-    UINTVAL num, STRING **d)>
-
+FUNCDOC:
 Repeats the specified Parrot string I<num> times and stores the result
 in the second string, and returns it. The second string is created if
 necessary.
 
-=cut
-
 */
 
 STRING *
 string_repeat(Interp *interpreter, const STRING *s,
     UINTVAL num, STRING **d)
 {
-    STRING *dest;
     UINTVAL i;
 
-    dest = string_make_direct(interpreter, NULL,
+    STRING * const dest = string_make_direct(interpreter, NULL,
                         s->bufused * num,
                         s->encoding, s->charset, 0);
 
@@ -1045,16 +914,11 @@ string_repeat(Interp *interpreter, const STRING *s,
 
 /*
 
-=item C<STRING *
-string_substr(Interp *interpreter, STRING *src,
-    INTVAL offset, INTVAL length, STRING **d, int replace_dest)>
-
+FUNCDOC:
 Copies the substring of length C<length> from C<offset> from the
 specified Parrot string and stores it in C<**d>, allocating memory if
 necessary. The substring is also returned.
 
-=cut
-
 */
 
 STRING *
@@ -1112,10 +976,7 @@ string_substr(Interp *interpreter, STRING *src,
 
 /*
 
-=item C<STRING *
-string_replace(Interp *interpreter, STRING *src,
-    INTVAL offset, INTVAL length, STRING *rep, STRING **d)>
-
+FUNCDOC:
 This should follow the Perl semantics for:
 
     substr EXPR, OFFSET, LENGTH, REPLACEMENT
@@ -1132,8 +993,6 @@ past the end of the string concatenates the two strings.
 
 A negative offset is allowed to replace from the end.
 
-=cut
-
 */
 
 STRING *
@@ -1268,16 +1127,13 @@ string_replace(Interp *interpreter, STRING *src,
 
 /*
 
-=item C<STRING *
-string_chopn(Interp *interpreter, STRING *s, INTVAL n, int in_place)>
+FUNCDOC:
 
 Chops off the last C<n> characters of the specified Parrot string. If
 C<n> is negative, cuts the string after C<+n> characters.
 If C<in_place> is true, the string is chopped in places, else a copy
 of the string is chopped and returned.
 
-=cut
-
 */
 
 STRING *
@@ -1332,8 +1188,7 @@ string_chopn(Interp *interpreter, STRING *s, INTVAL n, int in_place)
 
 
 INTVAL
-string_compare(Interp *interpreter,
-    STRING *s1, STRING *s2)
+string_compare(Interp *interpreter, STRING *s1, STRING *s2)
 {
     if (!s1 && !s2) {
         return 0;
@@ -1354,17 +1209,13 @@ string_compare(Interp *interpreter,
 
 /*
 
-=item C<INTVAL
-string_equal(Interp *interpreter, STRING *s1, STRING *s2)>
-
+FUNCDOC:
 Compares two Parrot strings, performing type and encoding conversions if
 necessary.
 
 Note that this function returns 0 if the strings are equal and 1
 otherwise.
 
-=cut
-
 */
 
 INTVAL
@@ -1404,20 +1255,15 @@ string_equal(Interp *interpreter, STRING *s1, STRING *s2)
 
 /*
 
-=item C<static void
-make_writable(Interp *interpreter, STRING **s,
-    const size_t len, parrot_string_representation_t representation)>
-
+FUNCDOC:
 Makes the specified Parrot string writable with minimum length C<len>.
 The C<representation> argument is required in case a new Parrot string
 has to be created.
 
-=cut
-
 */
 
 static void
-make_writable(Interp *interpreter, STRING **s,
+make_writable(Interp *interpreter, STRING **s /*NN*/,
     const size_t len, parrot_string_representation_t representation)
 {
     if (!*s)
@@ -1441,21 +1287,15 @@ do { \
 
 /*
 
-=item C<STRING *
-string_bitwise_and(Interp *interpreter, STRING *s1,
-    STRING *s2, STRING **dest)>
-
+FUNCDOC:
 Performs a bitwise C<AND> on two Parrot string, performing type and
 encoding conversions if necessary. If the second string is not C<NULL>
 then it is reused, otherwise a new Parrot string is created.
 
-=cut
-
 */
 
 STRING *
-string_bitwise_and(Interp *interpreter, STRING *s1,
-    STRING *s2, STRING **dest)
+string_bitwise_and(Interp *interpreter, STRING *s1, STRING *s2, STRING **dest)
 {
     STRING *res = NULL;
     size_t minlen;
@@ -1522,32 +1362,25 @@ do { \
         restype *dp; \
         size_t _index; \
      \
-    if (s1) \
-    { \
+    if (s1) { \
         curr1 = (type1 *)s1->strstart; \
         length1 = s1->strlen; \
     } \
-     \
-    if (s2) \
-    { \
+    if (s2) { \
         curr2 = (type2 *)s2->strstart; \
         length2 = s2->strlen; \
     } \
- \
     dp = (restype *)res->strstart; \
     _index = 0; \
  \
-    for ( ; _index < maxlen ; ++curr1, ++curr2, ++dp, ++_index) \
-    { \
-        if (_index < length1) \
-        { \
+    for ( ; _index < maxlen ; ++curr1, ++curr2, ++dp, ++_index) { \
+        if (_index < length1) { \
             if (_index < length2) \
                 *dp = *curr1 op *curr2; \
             else \
                 *dp = *curr1; \
         } \
-        else if (_index < length2) \
-        { \
+        else if (_index < length2) { \
             *dp = *curr2; \
         } \
     } \
@@ -1555,21 +1388,16 @@ do { \
 
 /*
 
-=item C<STRING *
-string_bitwise_or(Interp *interpreter,
-    STRING *s1, STRING *s2, STRING **dest)>
+FUNCDOC:
 
 Performs a bitwise C<OR> on two Parrot string, performing type and
 encoding conversions if necessary. If the second string is not C<NULL>
 then it is reused, otherwise a new Parrot string is created.
 
-=cut
-
 */
 
 STRING *
-string_bitwise_or(Interp *interpreter,
-    STRING *s1, STRING *s2, STRING **dest)
+string_bitwise_or(Interp *interpreter, STRING *s1, STRING *s2, STRING **dest)
 {
     STRING *res;
     size_t maxlen = 0;
@@ -1629,21 +1457,16 @@ string_bitwise_or(Interp *interpreter,
 
 /*
 
-=item C<STRING *
-string_bitwise_xor(Interp *interpreter,
-    STRING *s1, STRING *s2, STRING **dest)>
+FUNCDOC:
 
 Performs a bitwise C<XOR> on two Parrot strings, performing type and
 encoding conversions if necessary. If the second string is not C<NULL>
 then it is reused, otherwise a new Parrot string is created.
 
-=cut
-
 */
 
 STRING *
-string_bitwise_xor(Interp *interpreter,
-    STRING *s1, STRING *s2, STRING **dest)
+string_bitwise_xor(Interp *interpreter, STRING *s1, STRING *s2, STRING **dest)
 {
     STRING *res;
     size_t maxlen = 0;
@@ -1703,35 +1526,27 @@ string_bitwise_xor(Interp *interpreter,
 
 #define BITWISE_NOT_STRING(type, s, res) \
 do { \
-    if (s && res) \
-    { \
+    if (s && res) { \
         const type *curr = (type *)s->strstart; \
         size_t length = s->strlen; \
         Parrot_UInt1 *dp = (Parrot_UInt1 *)res->strstart; \
  \
         for ( ; length ; --length, ++dp, ++curr) \
-        { \
             *dp = 0xFF & ~ *curr; \
-        } \
     } \
 } while(0)
 
 /*
 
-=item C<STRING *
-string_bitwise_not(Interp *interpreter,
-    STRING *s, STRING **dest)>
+FUNCDOC:
 
 Performs a bitwise C<NOT> on a Parrot string. If the second string is
 not C<NULL> then it is reused, otherwise a new Parrot string is created.
 
-=cut
-
 */
 
 STRING *
-string_bitwise_not(Interp *interpreter,
-    STRING *s, STRING **dest)
+string_bitwise_not(Interp *interpreter, STRING *s, STRING **dest)
 {
     STRING *res;
     size_t len;
@@ -1781,37 +1596,30 @@ string_bitwise_not(Interp *interpreter,
 
 /*
 
-=item C<INTVAL
-string_bool(Interp *interpreter, const STRING *s)>
+FUNCDOC:
 
 Returns whether the specified Parrot string is true. A string is true
 if it is equal to anything other than C<0>, C<""> or C<"0">.
 
-=cut
-
 */
 
 INTVAL
 string_bool(Interp *interpreter, const STRING *s)
 {
-    INTVAL len;
+    const INTVAL len = string_length(interpreter, s);
 
-    len = string_length(interpreter, s);
-
-    if (len == 0) {
+    if (len == 0)
         return 0;
-    }
 
     if (len == 1) {
 
-        UINTVAL c = string_index(interpreter, s, 0);
+        const UINTVAL c = string_index(interpreter, s, 0);
 
-        /* relying on character literals being interpreted as ascii--may
-        not be correct on ebdic systems. use numeric value instead? */
-        if (c == '0') {
+        /* relying on character literals being interpreted as ASCII--may
+        not be correct on EBCDIC systems. use numeric value instead? */
+        if (c == '0')
             /* later, accept other chars with digit value 0? or, no */
             return 0;
-        }
     }
 
     return 1;                   /* it must be true */
@@ -1819,10 +1627,7 @@ string_bool(Interp *interpreter, const STRING *s)
 
 /*
 
-=item C<STRING*
-string_nprintf(Interp *interpreter,
-    STRING *dest, INTVAL bytelen, const char *format, ...)>
-
+FUNCDOC:
 This is like C<Parrot_snprintf()> except that it writes to and returns a
 Parrot string.
 
@@ -1832,8 +1637,6 @@ native string will be created. If C<bytelen> is 0, the behaviour becomes
 more C<sprintf>-ish than C<snprintf>-like. C<bytelen> is measured in the
 encoding of C<*dest>.
 
-=cut
-
 */
 
 STRING*
@@ -1865,13 +1668,11 @@ string_nprintf(Interp *interpreter,
 
 /*
 
-=item C<STRING*
-string_printf(Interp *interpreter, const char *format, ...)>
+
+FUNCDOC:
 
 Writes and returns a Parrot string.
 
-=cut
-
 */
 
 STRING*
@@ -1890,8 +1691,7 @@ string_printf(Interp *interpreter, const char *format, ...)
 
 /*
 
-=item C<INTVAL
-string_to_int(Interp *interpreter, const STRING *s)>
+FUNCDOC:
 
 Converts a numeric Parrot string to an integer value.
 
@@ -1908,8 +1708,6 @@ A number is such that:
 The integer value is the appropriate integer representation of such a
 number, rounding towards zero.
 
-=cut
-
 */
 
 INTVAL
@@ -1920,12 +1718,12 @@ string_to_int(Interp *interpreter, const STRING *s)
 
     if (s) {
         const char *start = s->strstart;
-        const char *end = start + s->bufused;
+        const char * const end = start + s->bufused;
         int sign = 1;
         INTVAL in_number = 0;
 
         while (start < end) {
-            unsigned char c = *start;
+            const unsigned char c = *start;
 
             if (isdigit(c)) {
                 in_number = 1;
@@ -1961,14 +1759,10 @@ string_to_int(Interp *interpreter, const STRING *s)
 
 /*
 
-=item C<FLOATVAL
-string_to_num(Interp *interpreter, const STRING *s)>
-
+FUNCDOC:
 Same as C<string_to_int()> except that a floating-point value is
 returned.
 
-=cut
-
 */
 
 FLOATVAL
@@ -1985,9 +1779,10 @@ string_to_num(Interp *interpreter, const STRING *s)
          * XXX C99 atof interpreters 0x prefix
          * XXX would strtod() be better for detecting malformed input?
          */
-        char *cstr = string_to_cstring(interpreter, const_cast(s));
-        char *p = cstr;
-        while (isspace(*p)) p++;
+        char * const cstr = string_to_cstring(interpreter, const_cast(s));
+        const char *p = cstr;
+        while (isspace(*p))
+            p++;
         f = atof(p);
         /* Not all atof()s return -0 from "-0" */
         if (*p == '-' && f == 0.0)
@@ -2008,7 +1803,7 @@ string_to_num(Interp *interpreter, const STRING *s)
 
     if (s) {
         UINTVAL idx = 0;
-        UINTVAL length = s->strlen;
+        const UINTVAL length = s->strlen;
         int sign = 1;
         INTVAL seen_dot = 0;
         INTVAL seen_e = 0;
@@ -2021,8 +1816,8 @@ string_to_num(Interp *interpreter, const STRING *s)
         FLOATVAL exp_log=10.0, exp_val=1.0;
 
         while (idx < length) {
-            UINTVAL c = string_index(interpreter, s, idx);
-            INTVAL df = Parrot_char_is_digit(interpreter, c);
+            const UINTVAL c = string_index(interpreter, s, idx);
+            const INTVAL df = Parrot_char_is_digit(interpreter, c);
 
             if (df && !digit_family)
                 digit_family = df;
@@ -2118,31 +1913,24 @@ string_to_num(Interp *interpreter, const STRING *s)
 
 /*
 
-=item C<STRING *
-string_from_int(Interp * interpreter, INTVAL i)>
-
+FUNCDOC:
 Returns a Parrot string representation of the specified integer value.
 
-=cut
-
 */
 
 STRING *
-string_from_int(Interp * interpreter, INTVAL i) {
+string_from_int(Interp * interpreter, INTVAL i)
+{
     char buf[128];
     return int_to_str(interpreter, buf, i, 10);
 }
 
 /*
 
-=item C<STRING *
-string_from_num(Interp * interpreter, FLOATVAL f)>
-
+FUNCDOC:
 Returns a Parrot string representation of the specified floating-point
 value.
 
-=cut
-
 */
 
 STRING *
@@ -2156,15 +1944,11 @@ string_from_num(Interp * interpreter, FLOATVAL f)
 
 /*
 
-=item C<char *
-string_to_cstring(Interp * interpreter, STRING * s)>
-
+FUNCDOC:
 Returns a C string for the specified Parrot string. Use
 C<string_cstring_free()> to free the string. Failure to do this will
 result in a memory leak.
 
-=cut
-
 */
 
 char *
@@ -2186,37 +1970,31 @@ string_to_cstring(Interp * interpreter, STRING * s)
 
 /*
 
-=item C<void
-string_cstring_free(void *ptr)>
-
+FUNCDOC:
 Free a string created by C<string_to_cstring()>.
 
 TODO - Hopefully this can be a go away at some point, as it's got all
 sorts of leak potential otherwise.
 
-=cut
-
 */
 
 void
-string_cstring_free(void *ptr) {
+string_cstring_free(void *ptr)
+{
     mem_sys_free(ptr);
 }
 
 /*
 
-=item C<void
-string_pin(Interp * interpreter, STRING * s)>
-
+FUNCDOC:
 Replace the specified Parrot string's managed buffer memory by system
 memory.
 
-=cut
-
 */
 
 void
-string_pin(Interp * interpreter, STRING * s) {
+string_pin(Interp * interpreter, STRING * s)
+{
     void *memory;
     INTVAL size;
 
@@ -2236,27 +2014,23 @@ string_pin(Interp * interpreter, STRING * s) {
 
 /*
 
-=item C<void
-string_unpin(Interp * interpreter, STRING * s)>
-
+FUNCDOC:
 Undo a C<string_pin()> so that the string once again uses managed
 memory.
 
-=cut
-
 */
 
 void
-string_unpin(Interp * interpreter, STRING * s) {
+string_unpin(Interp * interpreter, STRING * s)
+{
     void *memory;
     INTVAL size;
 
     /* If this string is not marked using system memory,
      * we just don't do this
      */
-    if (!(PObj_sysmem_TEST(s))) {
+    if (!(PObj_sysmem_TEST(s)))
         return;
-    }
 
     /* Parrot_unmake_COW(interpreter, s); XXX -lt: can not be cowed ??? */
     size = PObj_buflen(s);
@@ -2281,13 +2055,9 @@ string_unpin(Interp * interpreter, STRING * s) {
 
 /*
 
-=item C<size_t
-string_hash(Interp * interpreter, Hash *hash, STRING *s)>
-
+FUNCDOC:
 Returns the hash value for the specified Parrot string, caching it in
-C<s->hashval>.
-
-=cut
+C<< s->hashval >>.
 
 */
 
@@ -2310,22 +2080,13 @@ string_hash(Interp * interpreter, STRING *s, size_t seed)
 
 /*
 
-=item C<STRING *
-string_escape_string(Interp * interpreter, STRING *src)>
-
+FUNCDOC:
 Escape all non-ascii chars to backslash sequences. Control chars that
 C<string_unescape_cstring> can handle are esacped as I<\x>, as well
 as a double quote character. Other control chars and codepoints < 0x100 are
 escaped as I<\xhh>, codepoints up to 0xffff, as I<\uhhhh>, and codepoints
 greater than this as I<\x{hh...hh}>.
 
-=item C<STRING *
-string_escape_string_delimited(Interp * interpreter, STRING *src, UINTVAL len)>
-
-Like above but limit output to len chars (used for trace output of strings).
-
-=cut
-
 */
 
 STRING *
@@ -2335,12 +2096,20 @@ string_escape_string(Interp * interpreter, STRING *src)
             (UINTVAL) ~0);
 }
 
+
+/*
+
+FUNCDOC:
+Like above but limit output to len chars (used for trace output of strings).
+
+*/
+
 STRING *
 string_escape_string_delimited(Interp * interpreter,
         STRING *src, UINTVAL limit)
 {
     STRING *result, *hex;
-    UINTVAL c, i, len, charlen;
+    UINTVAL i, len, charlen;
     String_iter iter;
     unsigned char *dp;
 
@@ -2360,7 +2129,7 @@ string_escape_string_delimited(Interp * interpreter,
     ENCODING_ITER_INIT(interpreter, src, &iter);
     dp = result->strstart;
     for (i = 0; len > 0; --len) {
-        c = iter.get_and_advance(interpreter, &iter);
+        UINTVAL c = iter.get_and_advance(interpreter, &iter);
         if (c < 0x7f) {
             /* process ASCII chars */
             if (i >= charlen - 2) {
@@ -2432,10 +2201,7 @@ string_escape_string_delimited(Interp * interpreter,
 }
 /*
 
-=item C<STRING *
-string_unescape_cstring(Interp * interpreter,
-    char *cstring, char delimiter, char *charset)>
-
+FUNCDOC:
 Unescapes the specified C string. These sequences are covered:
 
   \xhh        1..2 hex digits
@@ -2446,8 +2212,6 @@ Unescapes the specified C string. These sequences are covered:
   \Uhhhhhhhh  8 hex digits
   \a, \b, \t, \n, \v, \f, \r, \e
 
-=cut
-
 */
 
 
@@ -2473,7 +2237,8 @@ string_unescape_cstring(Interp * interpreter,
     if (!enc_char)
         enc_char = "ascii";
     /* check for encoding: */
-    if ( (p = strchr(enc_char, ':')) != 0) {
+    p = strchr(enc_char, ':');
+    if (p) {
         *p = '\0';
         encoding = Parrot_find_encoding(interpreter, enc_char);
         if (!encoding) {
@@ -2536,16 +2301,12 @@ string_unescape_cstring(Interp * interpreter,
 
 /*
 
-=item C<STRING *
-string_upcase(Interp *interpreter, const STRING *s)>
-
+FUNCDOC:
 Returns a copy of the specified Parrot string converted to upper case.
 Non-caseable characters are left unchanged.
 
 TODO - implemented only for ASCII.
 
-=cut
-
 */
 
 
@@ -2556,20 +2317,16 @@ string_upcase(Interp *interpreter, const STRING *s)
         const void * __c_ptr;
         void * __ptr;
     } __ptr_u;
-    STRING *dest = string_copy(interpreter, const_cast(s));
+    STRING * const dest = string_copy(interpreter, const_cast(s));
     string_upcase_inplace(interpreter, dest);
     return dest;
 }
 
 /*
 
-=item C<void
-string_upcase_inplace(Interp *interpreter, STRING *s)>
-
+FUNCDOC:
 Converts the specified Parrot string to upper case.
 
-=cut
-
 */
 
 void
@@ -2583,14 +2340,10 @@ string_upcase_inplace(Interp *interpreter, STRING *s)
 
 /*
 
-=item C<STRING *
-string_downcase(Interp *interpreter, const STRING *s)>
-
+FUNCDOC:
 Returns a copy of the specified Parrot string converted to lower case.
 Non-caseable characters are left unchanged.
 
-=cut
-
 */
 
 STRING *
@@ -2600,20 +2353,16 @@ string_downcase(Interp *interpreter, const STRING *s)
         const void * __c_ptr;
         void * __ptr;
     } __ptr_u;
-    STRING *dest = string_copy(interpreter, const_cast(s));
+    STRING * const dest = string_copy(interpreter, const_cast(s));
     string_downcase_inplace(interpreter, dest);
     return dest;
 }
 
 /*
 
-=item C<void
-string_downcase_inplace(Interp *interpreter, STRING *s)>
-
+FUNCDOC:
 Converts the specified Parrot string to lower case.
 
-=cut
-
 */
 
 void
@@ -2633,14 +2382,10 @@ string_downcase_inplace(Interp *interpreter, STRING *s)
 
 /*
 
-=item C<STRING *
-string_titlecase(Interp *interpreter, const STRING *s)>
-
+FUNCDOC:
 Returns a copy of the specified Parrot string converted to title case.
 Non-caseable characters are left unchanged.
 
-=cut
-
 */
 
 STRING *
@@ -2650,20 +2395,16 @@ string_titlecase(Interp *interpreter, const STRING *s)
         const void * __c_ptr;
         void * __ptr;
     } __ptr_u;
-    STRING *dest = string_copy(interpreter, const_cast(s));
+    STRING * const dest = string_copy(interpreter, const_cast(s));
     string_titlecase_inplace(interpreter, dest);
     return dest;
 }
 
 /*
 
-=item C<void
-string_titlecase_inplace(Interp *interpreter, STRING *s)>
-
+FUNCDOC:
 Converts the specified Parrot string to title case.
 
-=cut
-
 */
 
 void
@@ -2677,12 +2418,9 @@ string_titlecase_inplace(Interp *interpreter, STRING *s)
 
 /*
 
-=item C<STRING *string_increment(Interp *, const STRING *)>
-
+FUNCDOC:
 Perl5ish increment the string. Currently single char only.
 
-=cut
-
 */
 
 STRING *
@@ -2706,17 +2444,14 @@ string_increment(Interp *interpreter, const STRING *s)
 
 /*
 
-=item C<const char *Parrot_string_cstring(Interp *, const STRING *)>
-
+FUNCDOC:
 Return a C string from a Parrot string.  Both sides are treated
 as constants -- i.e. do not resize the result.
 
-=cut
-
 */
 
 const char *
-Parrot_string_cstring(Interp *interpreter, const STRING *str)
+Parrot_string_cstring(Interp *interpreter, const STRING *str /*NN*/)
 {
     /* TODO handle NUL and friends */
     return str->strstart;
@@ -2725,15 +2460,11 @@ Parrot_string_cstring(Interp *interpreter, const STRING *str)
 
 /*
 
-=item C<
-Parrot_string_is_cclass(Interp *, PARROT_CCLASS_FLAGS flags, STRING *s, UINTVAL offset)>
-
+FUNCDOC:
 Return 1 if the codepoint of string C<s> at given offset is in the given
 character class C<flags>. See also F<include/parrot/cclass.h> for possible
 character classes. Returns 0 otherwise, or if the string is empty or NULL.
 
-=cut
-
 */
 
 INTVAL
@@ -2762,19 +2493,10 @@ Parrot_string_find_not_cclass(Interp *interpreter, PARROT_CCLASS_FLAGS flags, ST
 
 /*
 
-=item C< STRING*
-Parrot_string_trans_charset(Interp *interpreter, STRING *src,
-        INTVAL charset_nr, STRING *dest)>
-
-=item C< STRING*
-Parrot_string_trans_encoding(Interp *interpreter, STRING *src,
-        INTVAL charset_nr, STRING *dest)>
-
+FUNCDOC:
 If C<dest> == NULL convert  C<src> to the given charset or encoding inplace,
 else return a copy of C<src> with the charset/encoding in dest.
 
-=cut
-
 */
 
 STRING*
@@ -2813,6 +2535,14 @@ Parrot_string_trans_charset(Interp *interpreter, STRING *src,
     return new_charset->to_charset(interpreter, src, dest);
 }
 
+/*
+
+FUNCDOC:
+If C<dest> == NULL convert  C<src> to the given charset or encoding inplace,
+else return a copy of C<src> with the charset/encoding in dest.
+
+*/
+
 STRING*
 Parrot_string_trans_encoding(Interp *interpreter, STRING *src,
         INTVAL encoding_nr, STRING *dest)
@@ -2854,9 +2584,70 @@ string_compose(Interp * interpreter, STRING *src)
         return string_make_empty(interpreter, enum_stringrep_one, 0);
     return CHARSET_COMPOSE(interpreter, src);
 }
-/*
 
-=back
+STRING* 
+string_join(Interp *interpreter, STRING *j, PMC *ar)
+{
+    STRING *res;
+    STRING *s;
+    int i, ar_len = VTABLE_elements(interpreter, ar);
+
+    if (ar_len == 0) {
+	return string_make_empty(interpreter, enum_stringrep_one, 0);
+    }
+    s = VTABLE_get_string_keyed_int(interpreter, ar, 0);
+    res = string_copy(interpreter, s);
+    for (i = 1; i < ar_len; ++i) {
+	res = string_append(interpreter, res, j, 0);
+	s = VTABLE_get_string_keyed_int(interpreter, ar, i);
+	res = string_append(interpreter, res, s, 0);
+    }
+    return res;
+}
+
+PMC* 
+string_split(Interp *interpreter, STRING *delim, STRING *str)
+{
+    PMC * const res =  pmc_new(interpreter, enum_class_ResizableStringArray);
+    const int slen = string_length(interpreter, str);
+    int dlen;
+    int ps,pe;
+
+    if (!slen)
+	return res;
+
+    dlen = string_length(interpreter, delim);
+    if (dlen == 0) {
+        int i;
+        VTABLE_set_integer_native(interpreter, res, slen);
+        for (i = 0; i < slen; ++i) {
+           STRING * const p = string_substr(interpreter, str, i, 1, NULL, 0);
+           VTABLE_set_string_keyed_int(interpreter, res, i, p);
+        }
+	return res;
+    }
+
+    pe = string_str_index(interpreter,str,delim,0);
+    if (pe < 0) {
+	VTABLE_push_string(interpreter,res,str);
+	return res;
+    }
+    ps = 0;
+    while (ps <= slen) {
+        const int pl = pe - ps;
+	STRING * const tstr = string_substr(interpreter, str, ps, pl, NULL, 0);
+	VTABLE_push_string(interpreter,res,tstr);
+	ps = pe + string_length(interpreter,delim);
+	if (ps > slen)
+	    break;
+        pe = string_str_index(interpreter,str,delim,ps);
+	if (pe < 0)
+	    pe = slen;
+    }
+    return res;
+}
+
+/*
 
 =head1 SEE ALSO
 
