@@ -1,6 +1,6 @@
 /*
-Copyright: 2001-2003 The Perl Foundation.  All Rights Reserved.
-$Id: sub.c 11975 2006-03-21 22:23:53Z bernhard $
+Copyright: 2001-2006 The Perl Foundation.  All Rights Reserved.
+$Id: sub.c 12188 2006-04-12 16:36:18Z leo $
 
 =head1 NAME
 
@@ -94,7 +94,7 @@ struct Parrot_sub *
 new_sub(Interp *interp)
 {
     /* Using system memory until I figure out GC issues */
-    struct Parrot_sub *newsub =
+    struct Parrot_sub * const newsub =
         mem_sys_allocate_zeroed(sizeof(struct Parrot_sub));
     newsub->seg = interp->code;
     return newsub;
@@ -116,7 +116,7 @@ XXX: Need to document semantics in detail.
 struct Parrot_sub *
 new_closure(Interp *interp)
 {
-    struct Parrot_sub *newsub = new_sub(interp);
+    struct Parrot_sub * const newsub = new_sub(interp);
     return newsub;
 }
 /*
@@ -136,8 +136,8 @@ to the current context.
 struct Parrot_cont *
 new_continuation(Interp *interp, struct Parrot_cont *to)
 {
-    struct Parrot_cont *cc = mem_sys_allocate(sizeof(struct Parrot_cont));
-    struct Parrot_Context *to_ctx = to ? to->to_ctx : CONTEXT(interp->ctx);
+    struct Parrot_cont * const cc = mem_sys_allocate(sizeof(struct Parrot_cont));
+    struct Parrot_Context * const to_ctx = to ? to->to_ctx : CONTEXT(interp->ctx);
 
     cc->to_ctx = to_ctx;
     cc->from_ctx = CONTEXT(interp->ctx);
@@ -168,7 +168,7 @@ Returns a new C<Parrot_cont> pointing to the current context.
 struct Parrot_cont *
 new_ret_continuation(Interp *interp)
 {
-    struct Parrot_cont *cc = mem_sys_allocate(sizeof(struct Parrot_cont));
+    struct Parrot_cont * const cc = mem_sys_allocate(sizeof(struct Parrot_cont));
     cc->to_ctx = CONTEXT(interp->ctx);
     cc->from_ctx = NULL;    /* filled in during a call */
     cc->seg = interp->code;
@@ -193,7 +193,7 @@ XXX: Need to document semantics in detail.
 struct Parrot_coro *
 new_coroutine(Interp *interp)
 {
-    struct Parrot_coro *co =
+    struct Parrot_coro * const co =
         mem_sys_allocate_zeroed(sizeof(struct Parrot_coro));
 
     co->seg = interp->code;
@@ -216,8 +216,7 @@ if possible; otherwise, creates a new one.
 PMC *
 new_ret_continuation_pmc(Interp * interpreter, opcode_t * address)
 {
-    PMC* continuation;
-    continuation = pmc_new(interpreter, enum_class_RetContinuation);
+    PMC* const continuation = pmc_new(interpreter, enum_class_RetContinuation);
     VTABLE_set_pointer(interpreter, continuation, address);
     return continuation;
 }
@@ -258,37 +257,43 @@ invalidate_retc_context(Interp *interpreter, PMC *cont)
 
 =item C<Parrot_full_sub_name>
 
-Print name and location of subroutine, This should finally use the label
-name of the frozen C<Sub> PMC image for now locate the C<Sub> name in
-the globals.
+Return namespace, name, and location of subroutine. 
 
 =cut
 
 */
 
+/* XXX use method lookup - create interface
+ *                         see also pbc.c
+ */
+extern PMC* Parrot_NameSpace_name(Interp* interpreter, PMC* pmc);
+
 STRING*
 Parrot_full_sub_name(Interp* interpreter, PMC* sub)
 {
     struct Parrot_sub * s;
     STRING *res;
 
+
     if (!sub || !VTABLE_defined(interpreter, sub))
         return NULL;
     s = PMC_sub(sub);
-    if (PMC_IS_NULL(s->namespace)) {
+    if (PMC_IS_NULL(s->namespace_stash)) {
         return s->name;
     } else {
-        Parrot_block_DOD(interpreter);
-        if (s->name) {
-	    STRING* ns = VTABLE_get_string(interpreter, s->namespace);
+        PMC *ns_array;
+        STRING *j;
 
-    	    ns = string_concat(interpreter, ns,
-		string_from_cstring(interpreter, " :: ", 4), 0);
-	    res =  string_concat(interpreter, ns, s->name, 0);
-        } else {
-	    STRING* ns = string_from_cstring(interpreter, "??? :: ", 7);
-	    res =  string_concat(interpreter, ns, s->name, 0);
-	}
+        Parrot_block_DOD(interpreter);
+        ns_array = Parrot_NameSpace_name(interpreter, s->namespace_stash);
+        if (s->name) {
+            VTABLE_push_string(interpreter, ns_array, s->name);
+        }
+        j = const_string(interpreter, ";");
+        /* shift toplevel - it doesn't have a name */
+        (void)VTABLE_shift_string(interpreter, ns_array);
+
+        res =  string_join(interpreter, j, ns_array);
         Parrot_unblock_DOD(interpreter);
         return res;
     }
@@ -333,10 +338,7 @@ Parrot_Context_info(Interp *interpreter, parrot_context_t *ctx,
         info->fullname = info->subname;
     } else {
         info->nsname = VTABLE_get_string(interpreter, sub->namespace);
-        info->fullname = string_concat(interpreter, info->nsname,
-        string_from_cstring(interpreter, " :: ", 4), 0);
-        info->fullname = string_concat(interpreter, info->fullname,
-        info->subname, 1);
+        info->fullname = Parrot_full_sub_name(interpreter, ctx->current_sub);
     }
 
     /* return here if there is no current pc */
@@ -378,10 +380,10 @@ STRING*
 Parrot_Context_infostr(Interp *interpreter, parrot_context_t *ctx)
 {
     struct Parrot_Context_info info;
-    const char* msg = (CONTEXT(interpreter->ctx) == ctx) ?
+    const char* const msg = (CONTEXT(interpreter->ctx) == ctx) ?
         "current instr.:":
         "called from Sub";
-    STRING *res = NULL;
+    STRING *res;
 
     Parrot_block_DOD(interpreter);
     if (Parrot_Context_info(interpreter, ctx, &info)) {
@@ -389,6 +391,8 @@ Parrot_Context_infostr(Interp *interpreter, parrot_context_t *ctx)
             "%s '%Ss' pc %d (%s:%d)", msg,
             info.fullname, info.pc, info.file, info.line);
     }
+    else
+        res = NULL;
     Parrot_unblock_DOD(interpreter);
     return res;
 }
@@ -406,12 +410,10 @@ Locate the LexPad containing the given name. Return NULL on failure.
 PMC*
 Parrot_find_pad(Interp* interpreter, STRING *lex_name, parrot_context_t *ctx)
 {
-    PMC *lex_pad;
-    parrot_context_t *outer;
-
     while (1) {
-        lex_pad = ctx->lex_pad;
-        outer = ctx->outer_ctx;
+        PMC * const lex_pad = ctx->lex_pad;
+        parrot_context_t * const outer = ctx->outer_ctx;
+
         if (!outer)
             return lex_pad;
         if (!PMC_IS_NULL(lex_pad)) {
@@ -444,7 +446,6 @@ parrot_new_closure(Interp *interpreter, PMC *sub_pmc)
     parrot_context_t *ctx;
 
     clos_pmc = VTABLE_clone(interpreter, sub_pmc);
-    clos_pmc->vtable = interpreter->vtables[enum_class_Closure];
     sub = PMC_sub(sub_pmc);
     clos = PMC_sub(clos_pmc);
     /* 
