@@ -1,6 +1,6 @@
 /*
 Copyright: 2001-2003 The Perl Foundation.  All Rights Reserved.
-$Id: utils.c 11737 2006-02-25 11:58:21Z leo $
+$Id: utils.c 12592 2006-05-10 04:55:00Z petdance $
 
 =head1 NAME
 
@@ -100,7 +100,7 @@ floatval_mod(FLOATVAL n2, FLOATVAL n3)
   /* Another workaround for buggy code generation in the lcc compiler-
    * adding a temporary variable makes it pass the test.
    */
-  FLOATVAL temp = n3 * floor(n2 / n3);
+  const FLOATVAL temp = n3 * floor(n2 / n3);
 
   return n3
      ? (n2 - temp)
@@ -449,16 +449,15 @@ Used in C<src/nci.c>.
 
 void *
 Parrot_make_la(Interp *interpreter, PMC *array) {
-    INTVAL arraylen = VTABLE_elements(interpreter, array);
-    long *out_array = NULL;
-    INTVAL cur = 0;
+    const INTVAL arraylen = VTABLE_elements(interpreter, array);
+    INTVAL cur;
 
     /* Allocate the array and set the last element to 0. Since we
        always allocate one element more than we use we're guaranteed
        to actually have an array, even if the inbound array is
        completely empty
     */
-    out_array = mem_sys_allocate((sizeof(long)) * (arraylen + 1));
+    long * const out_array = mem_sys_allocate((sizeof(long)) * (arraylen + 1));
     out_array[arraylen] = 0;
     /*    printf("Long array has %i elements\n", arraylen);*/
     for (cur = 0; cur < arraylen; cur++) {
@@ -501,16 +500,15 @@ Currently unused.
 
 void *
 Parrot_make_cpa(Interp *interpreter, PMC *array) {
-    INTVAL arraylen = VTABLE_elements(interpreter, array);
-    char **out_array = NULL;
-    INTVAL cur = 0;
+    const INTVAL arraylen = VTABLE_elements(interpreter, array);
+    INTVAL cur;
 
     /* Allocate the array and set the last element to 0. Since we
        always allocate one element more than we use we're guaranteed
        to actually have an array, even if the inbound array is
        completely empty
     */
-    out_array = mem_sys_allocate((sizeof(char *)) * (arraylen + 1));
+    char ** const out_array = mem_sys_allocate((sizeof(char *)) * (arraylen + 1));
     out_array[arraylen] = 0;
 
     /*    printf("String array has %i elements\n", arraylen);*/
@@ -568,9 +566,9 @@ typedef enum {
 /* &end_gen */
 
 PMC*
-tm_to_array(Parrot_Interp interpreter, struct tm *tm)
+tm_to_array(Parrot_Interp interpreter, const struct tm *tm)
 {
-  PMC *Array = pmc_new(interpreter, enum_class_Array);
+  PMC * const Array = pmc_new(interpreter, enum_class_Array);
   VTABLE_set_integer_native(interpreter, Array, 9);
   VTABLE_set_integer_keyed_int(interpreter, Array, 0, tm->tm_sec);
   VTABLE_set_integer_keyed_int(interpreter, Array, 1, tm->tm_min);
@@ -687,13 +685,6 @@ TODO add a define, if it's implemented so that we can start filling the gaps
 /* proto TODO mv to hdr */
 typedef int (*reg_move_func)(Interp*, unsigned char d, unsigned char s, void *);
 
-void 
-Parrot_register_move(Interp *, int n_regs,
-        unsigned char *dest_regs, unsigned char *src_regs,
-        unsigned char temp_reg, 
-        reg_move_func mov, 
-        reg_move_func mov_alt, 
-        void *info);
 void 
 Parrot_register_move(Interp *interpreter, int n_regs,
         unsigned char *dest_regs, unsigned char *src_regs,
