@@ -1,6 +1,6 @@
 /*
 Copyright: 2001-2003 The Perl Foundation.  All Rights Reserved.
-$Id: warnings.c 11709 2006-02-23 16:49:23Z leo $
+$Id: warnings.c 12101 2006-04-03 20:01:34Z petdance $
 
 =head1 NAME
 
@@ -36,10 +36,9 @@ Prints the bytecode location of the warning or error to C<PIO_STDERR>.
 void
 print_pbc_location(Parrot_Interp interpreter)
 {
-    Interp *tracer;
-
-    tracer = interpreter->debugger ? 
-        interpreter->debugger : interpreter;
+    Interp * const tracer =
+        interpreter->debugger ?
+            interpreter->debugger : interpreter;
     PIO_eprintf(tracer, "%Ss\n",
             Parrot_Context_infostr(interpreter, 
                 CONTEXT(interpreter->ctx)));
