@@ -1,6 +1,6 @@
 #!/usr/bin/perl
 
-# $Id$
+# $Id: mk_manifest_and_skip.pl 12600 2006-05-10 16:57:10Z bernhard $
 
 =head1 NAME
 
@@ -21,11 +21,11 @@ package main;
 
 use strict;
 use warnings;
-use 5.008;
 
 use File::Find;
 
 my @dirs;  # will be filled in wanted
+
 # XXX Most of these can propably be cleaned up
 my %special = qw(
     NEWS                                            [devel]doc
@@ -134,7 +134,12 @@ foreach my $dir (sort keys %ignore) {
 
 
 sub wanted {
+
     return if $File::Find::name =~ m[/\.svn|blib|debian];
+
+    # This is currently the only ignored directory    
+    return if $File::Find::name =~ m{runtime.parrot.library.PAST};
+
     $File::Find::name =~ s[^\./][];
     -d and push @dirs, $File::Find::name;
     -f and -e ".svn/text-base/$_.svn-base" and MANIFEST();
